@@ -17,7 +17,7 @@ class RawResponseData(TypedDict):
 class UserPayload(RawResponseData):
     """user payload"""
     user: Dict[str, Any]
-    applications: Dict[str, Any]
+    applications: list[dict[str, Any]]
 
 
 class LogsPayload(RawResponseData):
@@ -30,11 +30,6 @@ class BackupPayload(RawResponseData):
     backup: Dict[str, Any]
 
 
-class FullLogsPayload(RawResponseData):
-    """complete logs payload"""
-    url: Dict[str, Any]
-
-
 class StatusPayload(RawResponseData):
     """status payload"""
     # pylint: disable=invalid-name
